@@ -248,7 +248,6 @@ test_that("REST method prints message", {
   )
 })
 
-
 test_that("table is prepared from REST orgs response", {
   gitlab_org_rest_table <- test_rest_gitlab$prepare_orgs_table(
     orgs_list = test_mocker$use("gl_orgs_rest_list")
@@ -272,6 +271,7 @@ test_that("if get_orgs_from_host runs into GraphQL error, it switches to REST AP
     "rest_engine$get_orgs",
     test_mocker$use("gl_orgs_rest_list")
   )
+  gitlab_test_host_priv_2$is_public <- FALSE
   expect_snapshot(
     gitlab_orgs_vec <- gitlab_test_host_priv_2$get_orgs_from_host(
       output = "only_names",
@@ -287,6 +287,7 @@ test_that("if get_orgs_from_host runs into GraphQL error, it switches to REST AP
     orgs = "mbtests",
     mode = "private"
   )
+  gitlab_test_host_priv_2$is_public <- FALSE
   mockery::stub(
     gitlab_test_host_priv_2$get_orgs_from_host,
     "graphql_engine$get_orgs",
@@ -318,6 +319,7 @@ test_that("get_orgs_from_host works on GitHost level", {
     "graphql_engine$get_orgs",
     test_mocker$use("gl_orgs_full_response")
   )
+  gitlab_testhost_priv$is_public <- FALSE
   gitlab_orgs_table <- gitlab_testhost_priv$get_orgs_from_host(
     output = "full_table",
     verbose = FALSE
@@ -334,6 +336,7 @@ test_that("get_orgs_from_host prints message on number of organizations", {
     "rest_engine$get_orgs_count",
     3L
   )
+  gitlab_testhost_priv$is_public <- FALSE
   mockery::stub(
     gitlab_testhost_priv$get_orgs_from_host,
     "graphql_engine$get_orgs",
@@ -446,6 +449,16 @@ test_that("get_orgs_from_orgs_and_repos prints message when turning to REST engi
   )
 })
 
+test_that("get_orgs_from_host returns error when GitHost is public", {
+  gitlab_testhost_priv$is_public <- TRUE
+  expect_snapshot_error(
+    gitlab_testhost_priv$get_orgs_from_host(
+      output = "full_table",
+      verbose = FALSE
+    )
+  )
+})
+
 test_that("get_orgs works on GitHost level", {
   mockery::stub(
     gitlab_testhost$get_orgs,
